# Easierfile

[![PyPI Latest Release](https://img.shields.io/pypi/v/easierfile.svg)](https://pypi.org/project/easierfile/)
[![Package Status](https://img.shields.io/pypi/status/easierfile.svg)](https://pypi.org/project/easierfile/)
[![License](https://img.shields.io/pypi/l/easierfile.svg)](https://github.com/leoweyr/Python-Easierfile/blob/main/LICENSE)
[![Downloads](https://static.pepy.tech/personalized-badge/easierfile?period=total&units=international_system&left_color=grey&right_color=green&left_text=pypi%20downloads)](https://pepy.tech/project/easierfile)

A simple Python package that object-oriented encapsulates Python traditional built-in file operations. It's also easier than `easygui`. o((>ω< ))o

## ⚖️License

[MIT](https://github.com/leoweyr/Python-Easierfile/blob/main/LICENSE)

## 📗Documentation

The documentation is hosted on Github repository: https://github.com/leoweyr/Python-Easierfile/blob/main/doc